@@ -28,7 +28,7 @@ class HUBLogger:
         last, epoch, final_epoch, best_fitness, fi = args[:5]
         is_best = best_fitness == fi
 
-        if (time.time() - self.t) > 0:
+        if (time.time() - self.t) > self.rate_limit:
             print(f"{PREFIX}Submitting checkpoint for " + self.model_id)
             threading.Thread(target=self._upload_model, args=(epoch, is_best, last), daemon=True).start()
         self.t = time.time()
