@@ -2,7 +2,7 @@ import requests
 
 from .config import HUB_API_ROOT
 from .hub_logger import HUBLogger
-from .utils.general import colorstr
+from .utils.general import colorstr, emojis
 from .yolov5_wrapper import YOLOv5Wrapper as YOLOv5
 
 PREFIX = colorstr('Ultralytics: ')
@@ -39,7 +39,8 @@ class Trainer:
                 print(f"{PREFIX}ERROR: Unable to fetch model")
                 return None  # Cannot train without model
             elif not res["data"]:
-                print(f"{PREFIX}No models to train. Create YOLOv5 models to train at https://hub.ultralytics.com")
+                print(emojis(f"{PREFIX}No models to train. "
+                             f"Create YOLOv5 🚀 models to train at https://hub.ultralytics.com"))
                 return None  # Cannot train without model
             else:
                 self.model_id = res["data"]["id"]  # Append id as it may be fetched from queue and unknown
