@@ -1,6 +1,6 @@
 import importlib  # To import YOLOv5 as module
-import os
 import subprocess
+from pathlib import Path
 
 from .config import REPO_URL, REPO_BRANCH, ENVIRONMENT
 
@@ -16,11 +16,11 @@ def install_dependencies():
     print('Done')
 
 
-def verify_install():
+def clone_yolo():
     """
     Check that YOLOv5 is on the system and clone if not found
     """
-    if not os.path.isdir("./yolov5"):
+    if not Path("./yolov5").is_dir():
         from git import Repo
         try:
             print(f"Cloning YOLOv5 🚀 from {REPO_URL}...", end=" ")
@@ -33,9 +33,6 @@ def verify_install():
             print('Error: ' + str(e))
 
 
-verify_install()
-
-
 class YOLOv5Wrapper:
     def export(**kwargs):
         """Calls the YOLOv5 export module"""
